define(['dom', 'sandbox', '../collections/requests', './requests', 'text!../templates/base.html', 'text!../templates/no_pending_requests.html', 'text!../templates/no_pending_requests_read_only.html', 'core_lib/alerts'],
  function($, sandbox, RequestsCollection, RequestsView, template, no_requests_template, no_requests_template_read_only, Alerts) {

  var Application = sandbox.mvc.Layout({

    template: template,

    regions: {
      requests_container: '#certificates-requests-container'
    },

    ui: {
      loading_message: '#certificates-loading-message',
      requests_container: '#certificates-requests-container',
      no_requests_container: '#certificates-no-requests-container'
    },

    initialize: function(options) {

      if (!options.skip_stylesheet) {
        sandbox.io.load_stylesheet('../applications/certificates/css/certificates.css');
      }

      this.requests = options.requests || new RequestsCollection;

      this.bindTo(this.requests, 'reset', this.show_list, this);

      var req = this.requests.fetch();

      req.fail($.proxy(function() {

        var alert = new Alerts.error({
          hide_close_button: true,
          content: 'An error occured trying to load the certificate requests. <a href="' + sandbox.paths.base_url + '">Reload</a> this page to try again.'
        }).render();

        this.ui.loading_message.html(alert.el);

      }, this));
    },

    show_list: function() {

      this.ui.loading_message.hide();

      if (this.requests.length > 0) {

        this.requests_view = new RequestsView({
          collection: this.requests
        });

        this.requests_container.show(this.requests_view);

      } else {
        if (this.core.user.read_write()) {
          this.ui.no_requests_container.html(sandbox.template.parse(no_requests_template));
        } else {
          this.ui.no_requests_container.html(sandbox.template.parse(no_requests_template_read_only));
        }
      }
    }

  });

  return Application;

});
